@@ -123,7 +123,7 @@ class FileCall(BaseCall):
         fname = None
         disposition = self.response_data[0].get('content-disposition')
         if disposition:
-            fname = re.search(r'filename="(.+?)"', disposition, re.I).group(1)
+            fname = re.search(r'.*?filename="(.+?)"', disposition, re.I).group(1)
             fname = re.sub(r'[^a-z0-9-_\. ]', '-', fname, 0, re.I).lstrip('.')
 
         self.filename = fname
